@@ -1,4 +1,3 @@
-from typing import List
 import unittest
 import sys
 import os
@@ -61,6 +60,21 @@ class test_consoleiotools(unittest.TestCase):
             cit.echo("ABC", bar="BAR")
             self.assertEqual(fake_out.getvalue(), "BAR ABC\n")
 
+    def test_echo_indent(self):
+        with patch("sys.stdout", new=StringIO()) as fake_out:
+            cit.echo("ABC", indent=1)
+            self.assertEqual(fake_out.getvalue(), "│ ├── ABC\n")
+
+    def test_echo_indent_leaf(self):
+        with patch("sys.stdout", new=StringIO()) as fake_out:
+            cit.echo("ABC", indent=-1)
+            self.assertEqual(fake_out.getvalue(), "│ ╰── ABC\n")
+
+    def test_echo_indent_stem(self):
+        with patch("sys.stdout", new=StringIO()) as fake_out:
+            cit.echo("ABC", indent=2)
+            self.assertEqual(fake_out.getvalue(), "│ ╷   ├── ABC\n")
+
     def test_markdown(self):
         with patch("sys.stdout", new=StringIO()) as fake_out:
             cit.markdown("### ABC")
@@ -69,20 +83,20 @@ class test_consoleiotools(unittest.TestCase):
     def test_panel(self):
         with patch("sys.stdout", new=StringIO()) as fake_out:
             cit.panel("ABC", title="ABC", subtitle="ABC", expand=False, style="dim")
-            self.assertEqual(fake_out.getvalue().strip(), """
-╭─ ABC ─╮
-│ ABC   │
-╰─ ABC ─╯
-            """.strip())
+            self.assertEqual(fake_out.getvalue().strip(), "\n".join([
+                "╭─ ABC ─╮",
+                "│ ABC   │",
+                "╰─ ABC ─╯",
+            ]))
 
     def test_title(self):
         with patch("sys.stdout", new=StringIO()) as fake_out:
             cit.title("ABC")
-            self.assertEqual(fake_out.getvalue().strip(), """
-╭─────╮
-│ ABC │
-╰─────╯
-            """.strip())
+            self.assertEqual(fake_out.getvalue().strip(), "\n".join([
+                "╭─────╮",
+                "│ ABC │",
+                "╰─────╯",
+            ]))
 
     def test_ask(self):
         with patch("sys.stdout", new=StringIO()) as fake_out:
@@ -109,6 +123,16 @@ class test_consoleiotools(unittest.TestCase):
             cit.mute("ABC")
             self.assertEqual(fake_out.getvalue(), "│ ABC\n")
 
+    def test_print(self):
+        with patch("sys.stdout", new=StringIO()) as fake_out:
+            cit.print("ABC")
+            self.assertEqual(fake_out.getvalue(), "ABC\n")
+
+    def test_print_escape(self):
+        with patch("sys.stdout", new=StringIO()) as fake_out:
+            cit.print(cit.escape("[test]ABC"))
+            self.assertEqual(fake_out.getvalue(), "[test]ABC\n")
+
     def test_pause(self):
         with patch("sys.stdin", new=StringIO("\n")):  # simulate press enter
             cit.pause()
@@ -147,10 +171,10 @@ class test_consoleiotools(unittest.TestCase):
             self.assertEqual(userinput, "answer")
 
     def test_get_input_strip(self):
-        with patch("sys.stdout", new=StringIO()) as fake_out, patch("sys.stdin", new=StringIO("  ABC  \n")):
+        with patch("sys.stdout", new=StringIO()), patch("sys.stdin", new=StringIO("  ABC  \n")):
             userinput = cit.get_input(strip=True)
             self.assertEqual(userinput, "ABC")
-        with patch("sys.stdout", new=StringIO()) as fake_out, patch("sys.stdin", new=StringIO("  ABC  \n")):
+        with patch("sys.stdout", new=StringIO()), patch("sys.stdin", new=StringIO("  ABC  \n")):
             userinput = cit.get_input(strip=False)
             self.assertEqual(userinput, "  ABC  ")
 
@@ -161,7 +185,7 @@ class test_consoleiotools(unittest.TestCase):
             self.assertIn("2) DEF", fake_out.getvalue())
 
     def test_get_choice_string(self):
-        with patch("sys.stdout", new=StringIO()) as fake_out, patch("sys.stdin", new=StringIO("ABC\n")):
+        with patch("sys.stdout", new=StringIO()), patch("sys.stdin", new=StringIO("ABC\n")):
             self.assertEqual(cit.get_choice(["ABC", "DEF"]), "ABC")
 
     def test_get_choices_done(self):
@@ -212,13 +236,13 @@ class test_consoleiotools(unittest.TestCase):
 
         with patch("sys.stdout", new=StringIO()) as fake_out:
             func()
-            self.assertEqual(fake_out.getvalue().strip(), """
-╭──────╮
-│ FUNC │
-╰──────╯
-ABC
-╰
-            """.strip())
+            self.assertEqual(fake_out.getvalue().strip(), "\n".join([
+                "╭──────╮",
+                "│ FUNC │",
+                "╰──────╯",
+                "ABC",
+                "╰",
+            ]))
 
     def test_as_session_2(self):
         @cit.as_session('DEF')
@@ -227,13 +251,13 @@ ABC
 
         with patch("sys.stdout", new=StringIO()) as fake_out:
             func()
-            self.assertEqual(fake_out.getvalue().strip(), """
-╭─────╮
-│ DEF │
-╰─────╯
-ABC
-╰
-            """.strip())
+            self.assertEqual(fake_out.getvalue().strip(), "\n".join([
+                "╭─────╮",
+                "│ DEF │",
+                "╰─────╯",
+                "ABC",
+                "╰",
+            ]))
 
     def test_as_session_3(self):
         @cit.as_session
@@ -242,13 +266,23 @@ ABC
 
         with patch("sys.stdout", new=StringIO()) as fake_out:
             underscore_orCamel()
-            self.assertEqual(fake_out.getvalue().strip(), """
-╭─────────────────────╮
-│ UNDERSCORE OR CAMEL │
-╰─────────────────────╯
-ABC
-╰
-            """.strip())
+            self.assertEqual(fake_out.getvalue().strip(), "\n".join([
+                "╭─────────────────────╮",
+                "│ UNDERSCORE OR CAMEL │",
+                "╰─────────────────────╯",
+                "ABC",
+                "╰",
+            ]))
+
+    def test_deprecated_by(self):
+        @cit.deprecated_by(print)
+        def old_func(s: str):
+            print("Calling old_func()")
+
+        with patch("sys.stderr", new=StringIO()) as fake_err, patch("sys.stdout", new=StringIO()) as fake_out:
+            old_func("ABC")
+            self.assertEqual(fake_out.getvalue().strip(), "ABC")
+            self.assertIn("DeprecationWarning: Function `old_func` is deprecated, now calling `print` instead.", fake_err.getvalue().strip())
 
     def test_write_file(self):
         content = "3.1415926"
@@ -264,12 +298,15 @@ ABC
         content = "3.1415926"
         len_write = cit.write_file(self.TMP_FILE, content)
         content_read = cit.read_file(self.TMP_FILE)
+        self.assertGreater(len_write, 0)
         self.assertEqual(content_read, content)
 
     def test_read_file_with_encoding(self):
         content = "3.1415926"
         len_write = cit.write_file(self.TMP_FILE, content)
         content_read, encoding = cit.read_file(self.TMP_FILE, with_encoding=True)
+        self.assertGreater(len_write, 0)
+        self.assertEqual(content_read, content)
         self.assertEqual(encoding, "utf-8")
 
 
